pub struct Veg { /* private fields */ }Expand description
Vec-like struct that provides methods for generating tables
See the example in the module documentation for a complete demonstration of all features.
Implementations
Sourceimpl Veg
impl Veg
Sourcepub fn markdown_with(
&self,
header: Option<&str>,
columns: Option<&[usize]>,
) -> Result<String>
pub fn markdown_with( &self, header: Option<&str>, columns: Option<&[usize]>, ) -> Result<String>
Generate a markdown table with custom settings
- Different header definition
- Column indices
use unicode_segmentation::UnicodeSegmentation;
assert_eq!("A\u{0336}B\u{0336}".graphemes(true).count(), 2);Errors
Returns an error if the number of given columns do not match the columns in the table